@@ -1,5 +1,5 @@
 from dataclasses import dataclass, field
-from typing import List, Dict
+from typing import List
 
 @dataclass
 class Price:
@@ -7,6 +7,7 @@ class Price:
     min_price: float = 0.0
     top_price: float = 0.0
     cautionhour_type: str = ""
+    dynamic_top_price: bool = False
 
 @dataclass
 class Charger:
