@@ -63,34 +63,34 @@ class IHubSensors:
             initval=0,
             startpeaks=options.startpeaks,
         )
-        if len(self.chargertype.charger.entities.chargerentity) > 0:
+        if len(self.chargertype.entities.chargerentity):
             self.chargerobject = ChargerObject(
-                data_type=self.chargertype.charger.native_chargerstates,
-                listenerentity=self.chargertype.charger.entities.chargerentity
+                data_type=self.chargertype.native_chargerstates,
+                listenerentity=self.chargertype.entities.chargerentity
             )
             resultdict[self.chargerobject.entity] = self.chargerobject.is_initialized
 
             self.carpowersensor = CarPowerSensor(
                 data_type=int,
-                listenerentity=self.chargertype.charger.entities.powermeter,
-                powermeter_factor=self.chargertype.charger.options.powermeter_factor,
+                listenerentity=self.chargertype.entities.powermeter,
+                powermeter_factor=self.chargertype.options.powermeter_factor,
                 hubdata=self,
                 init_override=True
             )
             self.chargerobject_switch = ChargerSwitch(
                 hass=state_machine,
                 data_type=bool,
-                listenerentity=self.chargertype.charger.entities.powerswitch,
+                listenerentity=self.chargertype.entities.powerswitch,
                 initval=False,
-                currentname=self.chargertype.charger.entities.ampmeter,
-                ampmeter_is_attribute=self.chargertype.charger.options.ampmeter_is_attribute,
+                currentname=self.chargertype.entities.ampmeter,
+                ampmeter_is_attribute=self.chargertype.options.ampmeter_is_attribute,
                 hubdata=self,
                 init_override=True
             )
 
         else:
             self.chargerobject = ChargerObject(
-                data_type=self.chargertype.charger.native_chargerstates,
+                data_type=self.chargertype.native_chargerstates,
                 listenerentity="no entity",
                 init_override=True
             )
@@ -98,17 +98,17 @@ class IHubSensors:
             
             self.carpowersensor = CarPowerSensor(
                 data_type=int,
-                listenerentity=self.chargertype.charger.entities.powermeter,
-                powermeter_factor=self.chargertype.charger.options.powermeter_factor,
+                listenerentity=self.chargertype.entities.powermeter,
+                powermeter_factor=self.chargertype.options.powermeter_factor,
                 hubdata=self
             )
             self.chargerobject_switch = ChargerSwitch(
                 hass=state_machine,
                 data_type=bool,
-                listenerentity=self.chargertype.charger.entities.powerswitch,
+                listenerentity=self.chargertype.entities.powerswitch,
                 initval=False,
-                currentname=self.chargertype.charger.entities.ampmeter,
-                ampmeter_is_attribute=self.chargertype.charger.options.ampmeter_is_attribute,
+                currentname=self.chargertype.entities.ampmeter,
+                ampmeter_is_attribute=self.chargertype.options.ampmeter_is_attribute,
                 hubdata=self
             )
         self.totalhourlyenergy = HubMember(
@@ -120,16 +120,11 @@ class IHubSensors:
     def init_hub_values(self):
         """Initialize values from Home Assistant on the set objects"""
         if self.chargerobject is not None:
-            self.chargerobject.value = self.state_machine.states.get(self.chargerobject.entity).state if self.state_machine.states.get(
-                self.chargerobject.entity) is not None else 0
-        self.chargerobject_switch.value = self.state_machine.states.get(
-            self.chargerobject_switch.entity).state if self.state_machine.states.get(
-            self.chargerobject_switch.entity) is not None else ""
+            self.chargerobject.value = self.state_machine.states.get(self.chargerobject.entity).state if self.state_machine.states.get(self.chargerobject.entity) is not None else 0
+        self.chargerobject_switch.value = self.state_machine.states.get(self.chargerobject_switch.entity).state if self.state_machine.states.get(self.chargerobject_switch.entity) is not None else ""
         self.chargerobject_switch.updatecurrent()
-        self.carpowersensor.value = self.state_machine.states.get(self.carpowersensor.entity).state if self.state_machine.states.get(
-            self.carpowersensor.entity) is not None else 0
-        self.totalhourlyenergy.value = self.state_machine.states.get(self.totalhourlyenergy.entity) if self.state_machine.states.get(
-            self.totalhourlyenergy.entity) is not None else 0
+        self.carpowersensor.value = self.state_machine.states.get(self.carpowersensor.entity).state if isinstance(self.state_machine.states.get(self.carpowersensor.entity),(float,int)) else 0
+        self.totalhourlyenergy.value = self.state_machine.states.get(self.totalhourlyenergy.entity) if isinstance(self.state_machine.states.get(self.totalhourlyenergy.entity),(float,int)) else 0
 
 
 @dataclass
