@@ -24,7 +24,7 @@ class Hoursselection:
                     )
                 )
         self.model.validate()
-        self.service = HourSelectionService(self.model, base_mock_hour)
+        self.service = HourSelectionService(parent=self, base_mock_hour=base_mock_hour)
     
     @property
     def offsets(self) -> dict:
@@ -80,6 +80,10 @@ class Hoursselection:
     def adjusted_average(self, val):
         self.model.adjusted_average = val
 
+    def update_top_price(self, dyn_top_price) -> None: 
+        self.model.options.set_absolute_top_price(dyn_top_price, self.model.options.min_price)
+        self.update(caller="today")
+
     def update(self, testhour:int = None, caller:str = None) -> None:
         if testhour is not None:
             self.service._mock_hour = testhour
@@ -113,12 +117,12 @@ class Hoursselection:
         def _looper_price(h:int, tomorrow_active:bool):
             if h in self.model.hours.dynamic_caution_hours:
                     if tomorrow_active:
-                        if h < hour and len(self.prices_tomorrow) > 0:
+                        if h < hour and len(self.prices_tomorrow):
                             ret[h] = self.model.hours.dynamic_caution_hours[h] * self.prices_tomorrow[h]
                     if h >= hour:
                         ret[h] = self.model.hours.dynamic_caution_hours[h] * self.prices[h]
             elif h not in self.model.hours.non_hours:
-                if h < hour and len(self.prices_tomorrow) > 0:
+                if h < hour and len(self.prices_tomorrow):
                     ret[h] = self.prices_tomorrow[h]
                 if h >= hour:
                     ret[h] = self.prices[h]
