@@ -1,6 +1,6 @@
 from datetime import datetime
 #from ...hub.hub import HubBase
-from ...models.chargerstates import CHARGERSTATES
+from ...models.chargecontroller_states import ChargeControllerStates
 from .thresholdbase import ThresholdBase
 
 
@@ -12,7 +12,7 @@ class Threshold(ThresholdBase):
     @property
     def allowedcurrent(self) -> int:
         amps = self._setcurrentdict()
-        if self._hub.chargecontroller.status is not CHARGERSTATES.Start.name:
+        if self._hub.chargecontroller.status is not ChargeControllerStates.Start.name:
             return min(amps.values())
         return ThresholdBase.allowed_current(
             datetime.now().minute,
